Checks whether Julia is set up correctly via JuliaConnectoR and the
DiDInt.jl package (version >= 0.9.6) is available. Used to guard
examples and tests that require a live Julia session.
Checks whether Julia is set up correctly via JuliaConnectoR and the
DiDInt.jl package (version >= 0.9.6) is available. Used to guard
examples and tests that require a live Julia session.