Skip to contents

Summary method for DiDIntObj

Usage

# S3 method for class 'DiDIntObj'
summary(object, level = c("all", "agg", "sub"), ...)

Arguments

object

A DiDIntObj object

level

Specify either "agg", "sub", or "all", to view the results at the aggregate level, the sub-aggregate level, or to view both simultaneously.

...

other arguments

Value

The DiDIntObj object, returned invisibly. Called for its side effect of printing summary results to the console.