Plot method for DiDIntPlotObj
Usage
# S3 method for class 'DiDIntPlotObj'
plot(x, y = NULL, ccc = "all", groupmin = 3, window = NULL, ...)Arguments
- x
A
DiDIntPlotObjobject.- y
NULLvalue passed toplot()method.- ccc
Specify which
cccoptions you would like plotted from the data. Any combination of"none","hom","time","state","add", and"int". Or, alternatively,"all"(default).- groupmin
The minimum number of states used to compute a point on the event study for which the confidence band should be shown. Defaults to
3.- window
Either
NULLor a vector with two elements defining the first and last period that should be plotted.- ...
other arguments